---
title: 인앱결제를 이용해야 하는 기준
category: 자주 묻는 질문 (일반 문의) > 일반 문의 > 자주 묻는 질문
tags:
  - 공통
searchTags:
  - PG결제
  - 스토어정책
  - 인앱결제
datetime: 2024-06-21T07:20:17.493Z
---

### **인앱결제란?**

<Callout content="**구글·애플이 자체 개발한 내부 결제 시스템으로, 유료 앱·콘텐츠를 결제하도록 하는 방식**을 말합니다." />

### **PG결제 or 인앱결제?**

<Callout content="각 스토어의 정책을 준수하여 가맹점의 제공 서비스가 인앱결제 대상 항목에 해당하는지 살펴보아야 합니다." />

- 앱스토어 정책 :  <https://developer.apple.com/kr/in-app-purchase/>
- 구글스토어 정책 :  <https://support.google.com/googleplay/android-developer/answer/10281818?hl=ko>

<Callout content="인앱결제 우회를 통한 결제구현 시, 스토어 정책에 따라 앱이 마켓에서 삭제 될 수 있으니 주의해 주세요." icon="💡" title="참고사항" />
